# latpypack


[![image](https://img.shields.io/pypi/v/latpypack.svg)](https://pypi.python.org/pypi/latpypack)
[![image](https://img.shields.io/conda/vn/conda-forge/latpypack.svg)](https://anaconda.org/conda-forge/latpypack)


**latihan buat package python**


-   Free software: MIT License
-   Documentation: https://fiopiohoho.github.io/latpypack
    

## Features

-   TODO
